@@ -25,7 +25,6 @@ from portable_python.versions import PPG
 
 
 LOG = logging.getLogger(__name__)
-REST_CLIENT = RestClient()
 RX_BINARY = re.compile(r"^.*\.(dylib|gmo|icns|ico|nib|prof.*|tar)$")
 
 
@@ -113,6 +112,9 @@ class BuildContext:
         runez.abort_if(v and v not in ("mount-shadow", "gettext-tiny"), f"Invalid isolation method '{v}'")
         self.isolate_usr_local = v
 
+    def __repr__(self):
+        return self.isolate_usr_local or "none"
+
     def __enter__(self):
         runez.Anchored.add(self.setup.folders.base_folder)
         if self.isolate_usr_local == "mount-shadow":
@@ -241,6 +243,7 @@ class BuildSetup:
         self.python_builder.validate_setup()
         self.log_counter = 0
         with BuildContext(self) as build_context:
+            self.build_context = build_context
             modules = self.python_builder.modules
             LOG.info("portable-python v%s, current folder: %s" % (runez.get_version(__name__), os.getcwd()))
             LOG.info(runez.joined(modules, list(modules)))
@@ -560,7 +563,7 @@ class ModuleBuilder:
                 basename = runez.basename(self.url, extension_marker="#")
                 path = self.setup.folders.sources / basename
                 if not path.exists():
-                    REST_CLIENT.download(self.url, path)
+                    RestClient().download(self.url, path)
 
                 runez.decompress(path, self.m_src_build, simplify=True)
 
